==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/CPUStressorFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CPUStressorFluent<A extends CPUStressorFluent<A>> extends BaseFluent<A>{
  public CPUStressorFluent() {
  }
  public CPUStressorFluent(CPUStressor instance) {
    instance = (instance != null ? instance : new CPUStressor());

    if (instance != null) {
      this.withLoad(instance.getLoad());
      this.withOptions(instance.getOptions());
      this.withWorkers(instance.getWorkers());
      this.withLoad(instance.getLoad());
      this.withOptions(instance.getOptions());
      this.withWorkers(instance.getWorkers());
    }
  }
  private Integer load;
  private List<String> options = new ArrayList<String>();
  private Integer workers;
  public Integer getLoad() {
    return this.load;
  }
  public A withLoad(Integer load) {
    this.load=load; return (A) this;
  }
  public boolean hasLoad() {
    return this.load != null;
  }
  public A addToOptions(int index,String item) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    this.options.add(index, item);
    return (A)this;
  }
  public A setToOptions(int index,String item) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    this.options.set(index, item); return (A)this;
  }
  public A addToOptions(java.lang.String... items) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    for (String item : items) {this.options.add(item);} return (A)this;
  }
  public A addAllToOptions(Collection<String> items) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    for (String item : items) {this.options.add(item);} return (A)this;
  }
  public A removeFromOptions(java.lang.String... items) {
    if (this.options == null) return (A)this;
    for (String item : items) { this.options.remove(item);} return (A)this;
  }
  public A removeAllFromOptions(Collection<String> items) {
    if (this.options == null) return (A)this;
    for (String item : items) { this.options.remove(item);} return (A)this;
  }
  public List<String> getOptions() {
    return this.options;
  }
  public String getOption(int index) {
    return this.options.get(index);
  }
  public String getFirstOption() {
    return this.options.get(0);
  }
  public String getLastOption() {
    return this.options.get(options.size() - 1);
  }
  public String getMatchingOption(Predicate<String> predicate) {
    for (String item: options) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingOption(Predicate<String> predicate) {
    for (String item: options) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOptions(List<String> options) {
    if (options != null) {this.options = new ArrayList(); for (String item : options){this.addToOptions(item);}} else { this.options = null;} return (A) this;
  }
  public A withOptions(java.lang.String... options) {
    if (this.options != null) {this.options.clear(); _visitables.remove("options"); }
    if (options != null) {for (String item :options){ this.addToOptions(item);}} return (A) this;
  }
  public boolean hasOptions() {
    return options != null && !options.isEmpty();
  }
  public Integer getWorkers() {
    return this.workers;
  }
  public A withWorkers(Integer workers) {
    this.workers=workers; return (A) this;
  }
  public boolean hasWorkers() {
    return this.workers != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CPUStressorFluent that = (CPUStressorFluent) o;
    if (!java.util.Objects.equals(load, that.load)) return false;

    if (!java.util.Objects.equals(options, that.options)) return false;

    if (!java.util.Objects.equals(workers, that.workers)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(load,  options,  workers,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (load != null) { sb.append("load:"); sb.append(load + ","); }
    if (options != null && !options.isEmpty()) { sb.append("options:"); sb.append(options + ","); }
    if (workers != null) { sb.append("workers:"); sb.append(workers); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/CPUStressorFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CPUStressorFluent<A extends CPUStressorFluent<A>> extends BaseFluent<A>{
  public CPUStressorFluent() {
  }
  
  public CPUStressorFluent(CPUStressor instance) {
    this.copyInstance(instance);
  }
  private Integer load;
  private List<String> options = new ArrayList<String>();
  private Integer workers;
  
  protected void copyInstance(CPUStressor instance) {
    instance = (instance != null ? instance : new CPUStressor());
  
    if (instance != null) {
        this.withLoad(instance.getLoad());
        this.withOptions(instance.getOptions());
        this.withWorkers(instance.getWorkers());
        this.withLoad(instance.getLoad());
        this.withOptions(instance.getOptions());
        this.withWorkers(instance.getWorkers());
      }
  }
  
  public Integer getLoad() {
    return this.load;
  }
  
  public A withLoad(Integer load) {
    this.load=load; return (A) this;
  }
  
  public boolean hasLoad() {
    return this.load != null;
  }
  
  public A addToOptions(int index,String item) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    this.options.add(index, item);
    return (A)this;
  }
  
  public A setToOptions(int index,String item) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    this.options.set(index, item); return (A)this;
  }
  
  public A addToOptions(java.lang.String... items) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    for (String item : items) {this.options.add(item);} return (A)this;
  }
  
  public A addAllToOptions(Collection<String> items) {
    if (this.options == null) {this.options = new ArrayList<String>();}
    for (String item : items) {this.options.add(item);} return (A)this;
  }
  
  public A removeFromOptions(java.lang.String... items) {
    if (this.options == null) return (A)this;
    for (String item : items) { this.options.remove(item);} return (A)this;
  }
  
  public A removeAllFromOptions(Collection<String> items) {
    if (this.options == null) return (A)this;
    for (String item : items) { this.options.remove(item);} return (A)this;
  }
  
  public List<String> getOptions() {
    return this.options;
  }
  
  public String getOption(int index) {
    return this.options.get(index);
  }
  
  public String getFirstOption() {
    return this.options.get(0);
  }
  
  public String getLastOption() {
    return this.options.get(options.size() - 1);
  }
  
  public String getMatchingOption(Predicate<String> predicate) {
    for (String item: options) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingOption(Predicate<String> predicate) {
    for (String item: options) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withOptions(List<String> options) {
    if (options != null) {this.options = new ArrayList(); for (String item : options){this.addToOptions(item);}} else { this.options = null;} return (A) this;
  }
  
  public A withOptions(java.lang.String... options) {
    if (this.options != null) {this.options.clear(); _visitables.remove("options"); }
    if (options != null) {for (String item :options){ this.addToOptions(item);}} return (A) this;
  }
  
  public boolean hasOptions() {
    return options != null && !options.isEmpty();
  }
  
  public Integer getWorkers() {
    return this.workers;
  }
  
  public A withWorkers(Integer workers) {
    this.workers=workers; return (A) this;
  }
  
  public boolean hasWorkers() {
    return this.workers != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CPUStressorFluent that = (CPUStressorFluent) o;
    if (!java.util.Objects.equals(load, that.load)) return false;
  
    if (!java.util.Objects.equals(options, that.options)) return false;
  
    if (!java.util.Objects.equals(workers, that.workers)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(load,  options,  workers,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (load != null) { sb.append("load:"); sb.append(load + ","); }
    if (options != null && !options.isEmpty()) { sb.append("options:"); sb.append(options + ","); }
    if (workers != null) { sb.append("workers:"); sb.append(workers); }
    sb.append("}");
    return sb.toString();
  }
  

}
